#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_TWO_PROD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_TWO_PROD_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/two_prod.hpp>

#endif
